#!/usr/bin/env python
# Created by "Thieu" at 21:37, 19/04/2022 ----------%                                                                               
#       Email: nguyenthieu2102@gmail.com            %                                                    
#       Github: https://github.com/thieu1995        %                         
# --------------------------------------------------%

from .multiply_ab import multiply as m2
from .multiply_abc import multiply as m3



#!/usr/bin/env python
# Created by "Thieu" at 21:28, 19/04/2022 ----------%                                                                               
#       Email: nguyenthieu2102@gmail.com            %                                                    
#       Github: https://github.com/thieu1995        %                         
# --------------------------------------------------%

import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="tcalculator",
    version="0.1.1",
    author="Thieu Nguyen",
    author_email="nguyenthieu2102@gmail.com",
    description="A small example package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/thieu1995/tcalculator",
    project_urls={
        "Bug Tracker": "https://github.com/thieu1995/tcalculator/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3.7",

    ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.6",
)
